@@ -15,20 +15,19 @@ def StatisticsBacktesting(Cerebro, margin, Mininbars = 0):
         MaxValue = max(ExpCloseDF['exp_close'])
         MinValue = min(ExpCloseDF['exp_close'])
 
-        count = sum(map(lambda x: x < 0, ExpCloseDF['exp_close']))
-        countzero = sum(map(lambda x: x == 0, ExpCloseDF['exp_close']))
-        countpos = sum(map(lambda x: x > 0, ExpCloseDF['exp_close']))
-        count_min = (count * 30) / 60
-        count_perc = round(count / (len(ExpCloseDF['exp_close']) - countzero), 5)
+        countneg = sum(map(lambda x: x < 0, ExpClosedf['exp_close']))
+        countzero = sum(map(lambda x: x == 0, ExpClosedf['exp_close']))
+        count_perc = round(DirX.DivByZero_int(countneg, (len(ExpCloseDF['exp_close']) - countzero)), 5)
         # count_perc = "{:.2%}".format(count_perc)
 
         trade_list = s.analyzers.trade_list.get_analysis()
         TradeLIST.append(trade_list)
         TradeListDF = pd.DataFrame(trade_list)
+
         try:
             totalnet_pnl = round((s.analyzers.TradeAnalyzer.rets.pnl.net.total), 2)
         except:
-            totalnet_pnl = 0
+            totalnet_pnl = np.nan
 
         ##Number of Trades
         try:
@@ -36,6 +35,8 @@ def StatisticsBacktesting(Cerebro, margin, Mininbars = 0):
         except:
             TotalTrades = 0
             print('No Trades')
+        if TotalTrades == 0:
+            TotalTrades = np.nan
 
         if TotalTrades > 0:
             ##  Total won
@@ -79,77 +80,93 @@ def StatisticsBacktesting(Cerebro, margin, Mininbars = 0):
                 won_perc = 0
                 print('No winning trades')
 
-        ### LONG
-        try:
-            LongTotal = s.analyzers.TradeAnalyzer.rets.long.total
-        except:
-            LongTotal = 0
-            print('No Trades')
+            ### LONG
+            try:
+                LongTotal = s.analyzers.TradeAnalyzer.rets.long.total
+            except:
+                LongTotal = 0
+                print('No Trades')
 
-        try:
-            LongWon = s.analyzers.TradeAnalyzer.rets.long.won
-        except:
-            LongWon = 0
-            print('No Trades')
+            try:
+                LongWon = s.analyzers.TradeAnalyzer.rets.long.won
+            except:
+                LongWon = 0
+                print('No Trades')
 
-        try:
-            LongPnl = s.analyzers.TradeAnalyzer.rets.long.pnl.total
-        except:
-            LongPnl = 0
-            print('No Trades')
+            try:
+                LongPnl = s.analyzers.TradeAnalyzer.rets.long.pnl.total
+            except:
+                LongPnl = 0
+                print('No Trades')
 
-        try:
-            LongPnlWon = s.analyzers.TradeAnalyzer.rets.long.pnl.won.total
-        except:
-            LongPnlWon = 0
-            print('No Trades')
+            try:
+                LongPnlWon = s.analyzers.TradeAnalyzer.rets.long.pnl.won.total
+            except:
+                LongPnlWon = 0
+                print('No Trades')
 
-        try:
-            LongPnlLost = s.analyzers.TradeAnalyzer.rets.long.pnl.lost.total
-        except:
-            LongPnlLost = 0
-            print('No Trades')
+            try:
+                LongPnlLost = s.analyzers.TradeAnalyzer.rets.long.pnl.lost.total
+            except:
+                LongPnlLost = 0
+                print('No Trades')
 
-        try:
-            ShortTotal = s.analyzers.TradeAnalyzer.rets.short.total
-        except:
-            ShortTotal = 0
-            print('No Trades')
+            ### SHORT
+            try:
+                ShortTotal = s.analyzers.TradeAnalyzer.rets.short.total
+            except:
+                ShortTotal = 0
+                print('No Trades')
 
-        ### SHORT
-        try:
-            ShortWon = s.analyzers.TradeAnalyzer.rets.short.won
-        except:
-            ShortWon = 0
-            print('No Trades')
+            try:
+                ShortWon = s.analyzers.TradeAnalyzer.rets.short.won
+            except:
+                ShortWon = 0
+                print('No Trades')
 
-        try:
-            ShortPnl = s.analyzers.TradeAnalyzer.rets.short.pnl.total
-        except:
-            ShortPnl = 0
-            print('No Trades')
+            try:
+                ShortPnl = s.analyzers.TradeAnalyzer.rets.short.pnl.total
+            except:
+                ShortPnl = 0
+                print('No Trades')
 
-        try:
-            ShortPnlWon = s.analyzers.TradeAnalyzer.rets.short.pnl.won.total
-        except:
-            ShortPnlWon = 0
-            print('No Trades')
+            try:
+                ShortPnlWon = s.analyzers.TradeAnalyzer.rets.short.pnl.won.total
+            except:
+                ShortPnlWon = 0
+                print('No Trades')
+
+            try:
+                ShortPnlLost = s.analyzers.TradeAnalyzer.rets.short.pnl.lost.total
+            except:
+                ShortPnlLost = 0
+                print('No Trades')
+
+        if TotalTrades == np.nan :
+            WonTotal = np.nan
+            LostTotal = np.nan
+            WonPnlTotal = np.nan
+            LostPnlTotal = np.nan
+            MaxWinning = np.nan
+            won_perc = np.nan
+            LongTotal = np.nan
+            LongWon = np.nan
+            LongPnl = np.nan
+            LongPnlWon = np.nan
+            LongPnlLost = np.nan
+            ShortTotal = np.nan
+            ShortWon = np.nan
+            ShortPnl = np.nan
+            ShortPnlWon = np.nan
+            ShortPnlLost = np.nan
 
-        try:
-            ShortPnlLost = s.analyzers.TradeAnalyzer.rets.short.pnl.lost.total
-        except:
-            ShortPnlLost = 0
-            print('No Trades')
 
         try:
             if won_perc == 1:
-                try:
-                    ADJ_Wc = ((WonTotal - np.sqrt(WonTotal))/ WonTotal)
-                    ADJ_W = ADJ_Wc * WonPnlTotal
-                    ADJ_W_BW = ADJ_Wc * (WonPnlTotal - MaxWinning)
-                    ADJ_L = 0
-                except:
-                    print('')
+                ADJ_Wc = ((WonTotal - np.sqrt(WonTotal))/ WonTotal)
+                ADJ_W = ADJ_Wc * WonPnlTotal
+                ADJ_W_BW = ADJ_Wc * (WonPnlTotal - MaxWinning)
+                ADJ_L = 0
             elif won_perc == 0:
                 ADJ_W = 0
                 ADJ_W_BW = 0
@@ -161,10 +178,10 @@ def StatisticsBacktesting(Cerebro, margin, Mininbars = 0):
                 ADJ_W_BW = ADJ_Wc * (WonPnlTotal - MaxWinning)
 
                 ADJ_L = ((LostTotal - np.sqrt(LostTotal))/ LostTotal) * LostPnlTotal
-            elif (TotalTrades) == 0:
-                ADJ_W_BW = 0
-                ADJ_W = 0
-                ADJ_L = 0
+            elif TotalTrades == np.nan:
+                ADJ_W_BW = np.nan
+                ADJ_W = np.nan
+                ADJ_L = np.nan
 
             ADJ_PNL = ADJ_W + ADJ_L
             PROM = round(ADJ_PNL / margin, 3)
@@ -172,12 +189,12 @@ def StatisticsBacktesting(Cerebro, margin, Mininbars = 0):
         except:
             pass
 
-        if TotalTrades== 0:
-            won_perc = np.nan
         try:
             if won_perc == 1:
                 profitfactor = np.inf
-            elif won_perc == 0 or won_perc == np.nan:
+            elif won_perc == 0 :
+                profitfactor = -np.inf
+            elif won_perc == np.nan:
                 profitfactor = np.nan
             else:
                 profitfactor = round(
@@ -189,13 +206,16 @@ def StatisticsBacktesting(Cerebro, margin, Mininbars = 0):
         ##  -----------------      LONG
 
         won_long_perc = round(DirX.DivByZero_int(LongWon, LongTotal),3)
+
         if LongTotal == 0:
             won_long_perc = np.nan
         # won_long_perc = "{:.2%}".format(won_long_perc)
 
         if won_long_perc == 1:
             profitfactorlong = np.inf
-        elif won_long_perc == 0 or won_long_perc == np.nan:
+        elif won_long_perc == 0 :
+            profitfactorlong = -np.inf
+        elif won_long_perc == np.nan:
             profitfactorlong = np.nan
         else:
             profitfactorlong = round(DirX.DivByZero_int(-LongPnlWon,LongPnlLost),3)
@@ -210,33 +230,33 @@ def StatisticsBacktesting(Cerebro, margin, Mininbars = 0):
 
         if won_short_perc == 1:
             profitfactorshort = np.inf
-        elif won_short_perc == 0 or won_short_perc == np.nan:
+        elif won_short_perc == 0 :
+            profitfactorshort = -np.inf
+        elif won_short_perc == np.nan:
             profitfactorshort = np.nan
         else:
             profitfactorshort = round(DirX.DivByZero_int(-ShortPnlWon,ShortPnlLost),
                 3)
 
+        try:
+            avg_bars_trade = round((TradeListDF['nbars'].mean()) * Mininbars / 60, 2)
+        except:
+            avg_bars_trade = np.nan
 
-        avg_bars_trade = round((TradeListDF['nbars'].mean()) * Mininbars / 60, 2)
         avg_pnl = round(DirX.DivByZero_int(totalnet_pnl, TotalTrades), 3)
 
-
         PNL_MDWD = round(DirX.DivByZero_int(-totalnet_pnl, MinValue), 3)
         if totalnet_pnl > 0 and MinValue == 0:
             PNL_MDWD = np.inf
         elif PNL_MDWD == 0:
             PNL_MDWD = np.nan
 
-
-        EXTFACT = round(DirX.DivByZero_int(MaxValue, MinValue), 3)
-        if EXTFACT <= -1:
-            EXTFACT = -EXTFACT
-        elif MaxValue > 0 and MinValue == 0:
+        EXTFACT = round(DirX.DivByZero_int(-MaxValue, MinValue), 3)
+        if MaxValue > 0 and MinValue == 0:
             EXTFACT = np.inf
         elif MaxValue == 0 and MinValue < 0:
             EXTFACT = -np.inf
 
-
         Analysislist = ([totalnet_pnl, won_perc, profitfactor,
                      round(LongPnl, 2), won_long_perc, profitfactorlong,
                      round(ShortPnl, 2), won_short_perc, profitfactorshort,
