@@ -16,11 +16,10 @@ def Statistics_OPT(opt_runs, margin, Mininbars = 0):
         MaxValue = max(ExpClosedf['exp_close'])
         MinValue = min(ExpClosedf['exp_close'])
 
-        count = sum(map(lambda x: x < 0, ExpClosedf['exp_close']))
+        countneg = sum(map(lambda x: x < 0, ExpClosedf['exp_close']))
         countzero = sum(map(lambda x: x == 0, ExpClosedf['exp_close']))
-        countpos = sum(map(lambda x: x > 0, ExpClosedf['exp_close']))
-        count_min = (count * 30) / 60
-        count_perc = round(count / (len(ExpClosedf['exp_close']) - countzero), 5)
+
+        count_perc = round(DirX.DivByZero_int(countneg, (len(ExpCloseDF['exp_close']) - countzero)), 5)
         # count_perc = "{:.2%}".format(count_perc)
 
         trade_list = s.analyzers.trade_list.get_analysis()
